@@ -1,5 +1,4 @@
 import datetime
-import logging
 
 import urllib.parse as urlparse
 
@@ -8,6 +7,7 @@ import requests
 
 from flask_oauthlib.client import OAuth, OAuthException
 
+from .logger import logger
 from .models import Models
 from .extensions import on_new_user, on_user_login, on_user_logout
 from .permissions import get_token
@@ -65,20 +65,29 @@ class Controllers:
             }
 
         self.enable_fake = not any([has_google, has_github])
+        logger.info(
+            'AUTH CONTROLLERS:' + 
+            (' google' if has_google else '') + 
+            (' github' if has_github else '') + 
+            (' fake' if self.enable_fake else '')
+        )
 
     # Public methods
     def authenticate(self, token, next, callback_url, private_key):
         """Check if user is authenticated
         """
+        logger.info('AUTH CONTROLLERS: authenticate %s %s %s' % (token is not None, next, callback_url))
         if token is not None:
             try:
                 token = jwt.decode(token, private_key)
             except jwt.InvalidTokenError:
+                logger.info('AUTH CONTROLLERS: invalid token %r' % token)
                 token = None
 
             if token is not None:
                 userid = token['userid']
                 user = self.models.get_user(userid)
+                logger.info('AUTH CONTROLLERS: userid %s found %s' % (userid, user is not None))
                 if user is not None:
                     ret = {
                         'authenticated': True,
@@ -177,10 +186,12 @@ class Controllers:
                        set_session=lambda k, v: None):
         """Callback from OAuth
         """
+        logger.info('AUTH CONTROLLERS: oauth_callback %s' % state)
         try:
             state = jwt.decode(state, private_key)
         except jwt.InvalidTokenError:
             state = {}
+        logger.info('AUTH CONTROLLERS: oauth_callback decoded %r' % state)
 
         resp = None
 
@@ -193,10 +204,12 @@ class Controllers:
             except OAuthException as e:
                 resp = e
             if isinstance(resp, OAuthException):
-                logging.error("OAuthException: %r", resp.data, exc_info=resp)
+                logger.error("OAuthException: %r", resp.data, exc_info=resp)
                 resp = None
         access_token = resp.get('access_token') if resp is not None else None
-        return self._next_url(state, access_token, private_key)
+        next_url = self._next_url(state, access_token, private_key)
+        logger.info('AUTH CONTROLLERS: oauth_callback next_url %s %s -> %s' % (state, access_token, next_url))
+        return next_url
 
 
     def resolve_username(self, username):
@@ -276,9 +289,9 @@ class Controllers:
         provider = state.get('provider')
         next_url = state.get('next', next_url)
         if access_token is not None and provider is not None:
-            logging.info('Got ACCESS TOKEN %r', access_token)
+            logger.info('Got ACCESS TOKEN %r', access_token)
             profile = self._get_user_profile(provider, access_token)
-            logging.info('Got PROFILE %r', profile)
+            logger.info('Got PROFILE %r', profile)
             client_token = self._get_token_from_profile(provider, profile, private_key)
             # Add client token to redirect url
             next_url = self._update_next_url(next_url, client_token)
@@ -312,7 +325,7 @@ class Controllers:
         user = self.models.create_or_get_user(userid, name, username, email, avatar_url)
         if user.get('new'):
             on_new_user(user)
-        logging.info('Got USER %r', user)
+        logger.info('Got USER %r', user)
         return self._get_token_from_userid(user['id'], private_key)
 
 
