@@ -1,7 +1,6 @@
 from importlib import import_module
 
-import logging
-
+from .logger import logger
 from .credentials import installed_extensions
 
 installed_modules = [
