@@ -1,8 +1,7 @@
 from importlib import import_module
 from importlib.util import find_spec
 
-import logging
-
+from .logger import logger
 from .credentials import allowed_services
 
 
@@ -20,7 +19,7 @@ def get_token(service, userid):
     try:
         get_permissions = module.get_permissions
     except AttributeError:
-        logging.warning("Can't find 'get_permissions' function in %s", module_name)
+        logger.warning("Can't find 'get_permissions' function in %s", module_name)
         return {}
 
     return get_permissions(service, userid)
